@@ -1,4 +1,4 @@
-// $Id: SpTraceVcd.cpp 11992 2006-01-16 18:59:58Z wsnyder $ -*- SystemC -*-
+// $Id: SpTraceVcd.cpp 22697 2006-07-10 14:56:22Z wsnyder $ -*- SystemC -*-
 //=============================================================================
 //
 // THIS MODULE IS PUBLICLY LICENSED
@@ -32,6 +32,53 @@
 //======================================================================
 //======================================================================
 
+//--------------------------------------------------
+#if (SYSTEMC_VERSION>=20050714)
+    // SystemC 2.1.v1
+void SpTraceFile::write_comment (const std::string &) {}
+void SpTraceFile::trace (const unsigned int &, const std::string &, const char **) {}
+
+# define DECL_TRACE_METHOD_A(tp) \
+    void SpTraceFile::trace( const tp& object, const std::string& name ) {}
+# define DECL_TRACE_METHOD_B(tp) \
+    void SpTraceFile::trace( const tp& object, const std::string& name, int width ) {}
+
+    DECL_TRACE_METHOD_A( bool )
+    DECL_TRACE_METHOD_A( sc_dt::sc_bit )
+    DECL_TRACE_METHOD_A( sc_dt::sc_logic )
+
+    DECL_TRACE_METHOD_B( unsigned char )
+    DECL_TRACE_METHOD_B( unsigned short )
+    DECL_TRACE_METHOD_B( unsigned int )
+    DECL_TRACE_METHOD_B( unsigned long )
+#ifdef SYSTEMC_64BIT_PATCHES
+    DECL_TRACE_METHOD_B( unsigned long long)
+#endif
+    DECL_TRACE_METHOD_B( char )
+    DECL_TRACE_METHOD_B( short )
+    DECL_TRACE_METHOD_B( int )
+    DECL_TRACE_METHOD_B( long )
+    DECL_TRACE_METHOD_B( sc_dt::int64 )
+    DECL_TRACE_METHOD_B( sc_dt::uint64 )
+
+    DECL_TRACE_METHOD_A( float )
+    DECL_TRACE_METHOD_A( double )
+    DECL_TRACE_METHOD_A( sc_dt::sc_int_base )
+    DECL_TRACE_METHOD_A( sc_dt::sc_uint_base )
+    DECL_TRACE_METHOD_A( sc_dt::sc_signed )
+    DECL_TRACE_METHOD_A( sc_dt::sc_unsigned )
+
+    DECL_TRACE_METHOD_A( sc_dt::sc_fxval )
+    DECL_TRACE_METHOD_A( sc_dt::sc_fxval_fast )
+    DECL_TRACE_METHOD_A( sc_dt::sc_fxnum )
+    DECL_TRACE_METHOD_A( sc_dt::sc_fxnum_fast )
+
+    DECL_TRACE_METHOD_A( sc_dt::sc_bv_base )
+    DECL_TRACE_METHOD_A( sc_dt::sc_lv_base )
+
+//--------------------------------------------------
+#elif (SYSTEMC_VERSION>20011000)
+    // SystemC 2.0.1
 void SpTraceFile::write_comment (const sc_string &) {}
 void SpTraceFile::trace (const unsigned int &, const sc_string &, const char **) {}
 
@@ -40,8 +87,6 @@ void SpTraceFile::trace (const unsigned int &, const sc_string &, const char **)
 #define DECL_TRACE_METHOD_B(tp) \
     void SpTraceFile::trace( const tp& object, const sc_string& name, int width ) {}
 
-#if (SYSTEMC_VERSION>20011000)
-    // SystemC 2.0.1
     DECL_TRACE_METHOD_A( bool )
     DECL_TRACE_METHOD_A( sc_bit )
     DECL_TRACE_METHOD_A( sc_logic )
@@ -72,8 +117,18 @@ void SpTraceFile::trace (const unsigned int &, const sc_string &, const char **)
     DECL_TRACE_METHOD_A( sc_fxnum_fast )
     DECL_TRACE_METHOD_A( sc_bv_base )
     DECL_TRACE_METHOD_A( sc_lv_base )
+
+//--------------------------------------------------
 #else
     // SystemC 1.2.1beta
+void SpTraceFile::write_comment (const sc_string &) {}
+void SpTraceFile::trace (const unsigned int &, const sc_string &, const char **) {}
+
+#define DECL_TRACE_METHOD_A(tp) \
+    void SpTraceFile::trace( const tp& object, const sc_string& name ) {}
+#define DECL_TRACE_METHOD_B(tp) \
+    void SpTraceFile::trace( const tp& object, const sc_string& name, int width ) {}
+
     DECL_TRACE_METHOD_A( bool )
     DECL_TRACE_METHOD_B( unsigned char )
     DECL_TRACE_METHOD_B( short unsigned int )
